import React from "react"
import ObjID from "../types/ObjID"
import  { ReactComponent as BreadcrumImage } from "./../assets/breadcrum.svg"
import { Link } from "react-router-dom"

interface Props{
    path?: ObjID
    onDirClick?: (path: ObjID) => void
}

const Breadcrum: React.FC<Props> = ({path,onDirClick}) => {

	if (!path){
		return <ul className="flex text-gray-500 dark:text-gray-400  text-lg ">
			<div className="breadcrum-item text-blue-500">
				<Link to="/f/">
					Home
				</Link>
			</div>
		</ul>
	}

	const keyParts = path.key.split("/").filter(e=>e.length > 0)

	return (
		<ul className="flex text-gray-500 dark:text-gray-400  text-lg ">
			<div className="breadcrum-item">
				<Link to="/f/">
					Home
				</Link>
			</div>
			<div className="breadcrum-item">
				<BreadcrumImage className="h-5 w-auto text-gray-400 cursor-default" />
				<li>
					<a className={!keyParts.length?"text-blue-500":""} onClick={()=>{
						onDirClick?.(new ObjID(path.bucket,"/"))
					}}>
						{path.bucket}
					</a>
				</li>
			</div>

			{keyParts.map((e,i,arr)=>{
				const last = i == arr.length - 1
				return <div key={e} className="breadcrum-item">
					<BreadcrumImage className="h-5 w-auto text-gray-400 cursor-default" />
					<li>
						<a 
							className={`${last?"text-blue-500":""}`}
							onClick={()=>{
								if (!last){
									onDirClick?.(new ObjID(path.bucket,arr.slice(0,i+1).join("/")))
								}
							}}>{e}</a>
					</li>
				</div>
			})}
		</ul>

	)
}

export default Breadcrum
