import React from "react"
import { FaRegFileAlt } from "react-icons/fa"
import { MdFolderOpen } from "react-icons/md"
import dateFormat from "../functions/dateFomat"
import sizeToReadable from "../functions/sizeToReadable"
import { Directory, File } from "../generated/graphql"
import ObjID from "../types/ObjID"
import Renameable from "./Renameable"
import Table, { Data, Row } from "./Table"

interface Props{
    directorys: Directory[]
    files: File[]
    
	onFileContext?: (event: React.MouseEvent, id: ObjID)=>void
    onDirContext?: (event: React.MouseEvent, path: ObjID)=>void
    onFileClick?: (event: React.MouseEvent,id: ObjID)=>void
    onDirClick?: (event: React.MouseEvent,path: ObjID)=>void

	editId?:  ObjID
	editEnable: boolean
	onRenameDone?: (id: ObjID, changed: boolean, newName: string)=>void
}

const FileBrowserList: React.FC<Props> = ({
	files,directorys,onDirClick,onDirContext,onFileClick,onFileContext,onRenameDone,editId,editEnable
}) => {

	const tableData: Data = {
		headers: [
			{name: "Name"},
			{name: "Last Modified"},
			{name: "Size"}
		],
		body:[
			...directorys.map((e):Row<Directory>=>{return {
				cells:[
					{
						name:e.name || "",
						component: <div>
							<MdFolderOpen className="inline" />
							<Renameable
								text={e.name || ""}
								edit={editEnable && (e.id === editId)}
								onRename={(newName)=>{e.name != newName?onRenameDone?.(e.id,true,newName):onRenameDone?.(e.id,false,newName)}}
								onCancleRename={()=>onRenameDone?.(e.id,false,"")}
							/>
						</div>
					}],
				data: e,
				onClick: ((e,data)=>onDirClick?.(e,data.id)),
				onContextMenu: ((e,data)=>onDirContext?.(e,data.id))
			}}),
			...files.map((e):Row<File>=>{return {
				cells:[
					{
						name:e.name || "",
						component: <div>
							<FaRegFileAlt className="inline" />
							<Renameable
								text={e.name || ""}
								edit={editEnable && (e.id === editId)}
								onRename={(newName)=>{e.name != newName?onRenameDone?.(e.id,true,newName):onRenameDone?.(e.id,false,newName)}}
								onCancleRename={()=>onRenameDone?.(e.id,false,"")}
							/>
						</div>
					},
					{name:dateFormat(e.lastModified)},{name:sizeToReadable(e.size)}],
				data: e,
				onClick: ((e,data)=>onFileClick?.(e,data.id)),
				onContextMenu: ((e,data)=>onFileContext?.(e,data.id))
			}}),
		],
		
	}

	return <Table data={tableData} />
}

export default FileBrowserList
