import React from "react"
import { useState } from "react"
import { useEffect } from "react"

interface Props {
	onDrop?: ()=>void
	onEnter?: (event: DragEvent)=>void
	onLeave?: (event: DragEvent)=>void
	onDragOver?: (event: DragEvent)=>void
	handleDrop?: (files: FileList)=>void
}

const GlobalDragAndDrop: React.FC<Props> = (props) => {
	const [hover,setHover] = useState(false)

	function handleDragEnter(event: DragEvent) {
		event.preventDefault()
		event.stopPropagation()
		setHover(true)
		props.onEnter?.(event)
	}

	function handleDragLeave(event: DragEvent) {
		event.preventDefault()
		event.stopPropagation()
		setHover(false)
		props.onLeave?.(event)
	}

	function handleDragOver(event:DragEvent) {
		event.preventDefault()
		event.stopPropagation()
		setHover(true)
		props.onDragOver?.(event)
	}

	function handleDrop(event: DragEvent) {
		event.preventDefault()
		event.stopPropagation()
		setHover(false)
		props.onDrop?.()
		if (event.dataTransfer?.files && event.dataTransfer.files.length > 0) {
			props.handleDrop?.(event.dataTransfer.files)
		}
	}

	useEffect(()=>{
		document.addEventListener("dragenter",handleDragEnter)
		document.addEventListener("dragleave",handleDragLeave)
		document.addEventListener("dragover",handleDragOver)
		document.addEventListener("drop",handleDrop)

		return ()=>{
			document.removeEventListener("dragenter",handleDragEnter)
			document.removeEventListener("dragleave",handleDragLeave)
			document.removeEventListener("dragover",handleDragOver)
			document.removeEventListener("drop",handleDrop)
			
		}
	
	},[])

	return (
		<div className={`fixed top-0 left-0 w-full h-full z-10 pointer-events-none
				${hover? "border-dashed border-gray-600 border-4":""}`} />
	)
}

export default GlobalDragAndDrop
